@@ -161,8 +161,10 @@ _notice_types = dict(
     GWHEN_COINC=168,
     AMON_ICECUBE_EHE=169,
     HAWC_BURST_MONITOR=171,
+    AMON_NU_EM_COINC=172,
     ICECUBE_ASTROTRACK_GOLD=173,
-    ICECUBE_ASTROTRACK_BRONZE=174)
+    ICECUBE_ASTROTRACK_BRONZE=174,
+    ICECUBE_CASCADE=176)
 
 vars().update(**_notice_types)
 NoticeType = IntEnum('NoticeType', _notice_types)
